@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
 """SatNOGS Network Auth0 login module admin class"""
-from __future__ import unicode_literals
-
 # from django.contrib import admin
 
 # Register your models here.
